cordex package
==============

Subpackages
-----------

.. toctree::

   cordex.core
   cordex.regions
   cordex.tables

Submodules
----------

cordex.cli module
-----------------

.. automodule:: cordex.cli
   :members:
   :undoc-members:
   :show-inheritance:

cordex.esgf\_access module
--------------------------

.. automodule:: cordex.esgf_access
   :members:
   :undoc-members:
   :show-inheritance:

cordex.shapes module
--------------------

.. automodule:: cordex.shapes
   :members:
   :undoc-members:
   :show-inheritance:

cordex.variable module
----------------------

.. automodule:: cordex.variable
   :members:
   :undoc-members:
   :show-inheritance:

cordex.version module
---------------------

.. automodule:: cordex.version
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cordex
   :members:
   :undoc-members:
   :show-inheritance:
